# OASYS 1.3
OASYS (OrAnge SYnchrotron Suite) is a graphical environment
for optic simulation software used in synchrotron facilities,
based on Orange 3.

OASYS package requires Python 3.8 or newer.

Instructions to install OASYS are here: https://github.com/oasys-kit/oasys-installation-scripts/wiki
